@@ -4,6 +4,27 @@ import (
 	"encoding/base64"
 )
 
+var base64RawFlag = Flag{
+	Name:  "raw",
+	Short: "r",
+	Desc:  "unpadded base64 encoding",
+	Value: false,
+	Type:  FlagBool,
+}
+
+func checkBase64RawFlag(f []Flag) bool {
+	raw := false
+	for _, flag := range f {
+		if flag.Name == "raw" || flag.Short == "r" {
+			r, ok := flag.Value.(bool)
+			if ok {
+				raw = r
+			}
+		}
+	}
+	return raw
+}
+
 // Base64Encode encode string to base64.
 type Base64Encode struct{}
 
@@ -15,12 +36,16 @@ func (p Base64Encode) Alias() []string {
 	return []string{"b64-enc", "b64-encode"}
 }
 
-func (p Base64Encode) Transform(data []byte, _ ...Flag) (string, error) {
+func (p Base64Encode) Transform(data []byte, f ...Flag) (string, error) {
+	raw := checkBase64RawFlag(f)
+	if raw {
+		return base64.RawStdEncoding.EncodeToString(data), nil
+	}
 	return base64.StdEncoding.EncodeToString(data), nil
 }
 
 func (p Base64Encode) Flags() []Flag {
-	return nil
+	return []Flag{base64RawFlag}
 }
 
 func (p Base64Encode) Title() string {
@@ -46,13 +71,20 @@ func (p Base64Decode) Alias() []string {
 	return []string{"b64-dec", "b64-decode"}
 }
 
-func (p Base64Decode) Transform(data []byte, _ ...Flag) (string, error) {
-	decodedString, err := base64.StdEncoding.DecodeString(string(data))
+func (p Base64Decode) Transform(data []byte, f ...Flag) (string, error) {
+	raw := checkBase64RawFlag(f)
+	var decodedString []byte
+	var err error
+	if raw {
+		decodedString, err = base64.RawStdEncoding.DecodeString(string(data))
+	} else {
+		decodedString, err = base64.StdEncoding.DecodeString(string(data))
+	}
 	return string(decodedString), err
 }
 
 func (p Base64Decode) Flags() []Flag {
-	return nil
+	return []Flag{base64RawFlag}
 }
 
 func (p Base64Decode) Title() string {
